[−][src]Module rscache::error
Error management.
Enums
| CacheError | Super error type for all sub cache errors |
| CompressionError | |
| ParseError | |
| ReadError |
Type Definitions
| Result | A specialized result type for cache operations. |
Error management.
| CacheError | Super error type for all sub cache errors |
| CompressionError | |
| ParseError | |
| ReadError |
| Result | A specialized result type for cache operations. |